##  Linking Existing Fact Sheets to the Reference Catalog
You can link existing business capabilities, applications, and IT components to the reference catalog in bulk or individually.
To link multiple fact sheets to the catalog in bulk, follow these steps:
  1. On the navigation bar, click More > Reference Catalog, then select a fact sheet type.
  2. On the reference catalog page, on the Unlinked tab, review and link multiple fact sheets in bulk. As a best practice, first, filter items with very high and high confidence levels and link them in bulk. After that, review the remaining items and link them individually.


To link an individual fact sheet to the catalog, follow these steps:
  1. Navigate to the fact sheet page.
  2. On the right-side pane, under Reference Catalog, click Start Linking.
  3. On the reference catalog page, review suggested items, select an appropriate item, then click Link.


**Note**
Providers and tech categories don’t have a direct connection to the catalog and can’t be linked manually. Within the context of the reference catalog, they’re treated as relations and are only created as related fact sheets when IT components or applications are linked to the catalog.
